Cls
===

The ``Cls`` class is a wrapper around your local Python classes. It can be sent to and live remotely on your compute,
then be called natively in Python from your local environment, while being run on remote compute.

Factory Method
~~~~~~~~~~~~~~

.. autofunction:: kubetorch.cls

Class
~~~~~

.. autoclass:: kubetorch.Cls
   :members:
   :inherited-members:

    .. automethod:: __init__
